pub struct CacheRadiusTracker { /* private fields */ }Expand description
Per-location TTL store of the walk’s cache radius.
The cache radius is the minimum LeadingAgreementBits of all servers that returned data
during the previous walk. It represents how far out caching has propagated: all servers
with LAB ≥ radius are likely to already hold cached data, so future walks can try a little further out, thereby alleviating load.
Implementations
Sourceimpl CacheRadiusTracker
impl CacheRadiusTracker
pub fn new(ttl: DurationMillis) -> Self
Sourcepub fn get(
&self,
location_id: Id,
now: TimeMillis,
) -> Option<LeadingAgreementBits>
pub fn get( &self, location_id: Id, now: TimeMillis, ) -> Option<LeadingAgreementBits>
Returns the cached radius if it has not expired.
Sourcepub fn update(
&self,
location_id: Id,
radius: LeadingAgreementBits,
now: TimeMillis,
)
pub fn update( &self, location_id: Id, radius: LeadingAgreementBits, now: TimeMillis, )
Replaces the stored radius unconditionally (each walk produces a fresh observation).